import * as express from 'express';
import * as morgan from 'morgan';
/**
 * Boostraps an Express-compatible middleware using Morgan.
 * Logs will be routed through :logger via the specified :level.
 * Tokens can be added using :additionalTokens and the :hostname
 * will be as specified.
 *
 * @param {CreateLoggerParameters} params
 * @param {Tokenizer[]} params.additionalTokens
 * @param {String} params.hostname
 * @param {LoggerInterface} params.logger
 * @param {String} params.level
 *
 * @throws {Error} when the :level` cannot be found in the :logger
 *
 * @return {express.RequestHandler}
 */
export declare function createMiddleware({ additionalTokens, hostname, logger, level, }?: CreateLoggerParameters): express.RequestHandler;
export declare function getZipkinTokenizers(): Tokenizer[];
export interface LoggerInterface {
    [key: string]: any;
}
export interface ExtendedRequest extends express.Request {
    [key: string]: any;
}
export interface ExtendedTokenCallbackFn extends morgan.TokenCallbackFn {
    (req: ExtendedRequest, res: express.Response): boolean | number | string;
}
export interface Tokenizer {
    id: string;
    fn: ExtendedTokenCallbackFn;
}
export interface CreateLoggerParameters {
    additionalTokens?: Tokenizer[];
    hostname?: string;
    logger?: LoggerInterface;
    level?: string;
}
